.. _kudos:

Kudos
=====
I want to say a big "thank you" to `Marshmallow
<https://github.com/marshmallow-code/marshmallow>`_ library for inspiration and to
it's authors who refused to accept my pull-requests and had me to start my own
library.
